==> ejc-middlemeasurement-impl-3.0.0-20240229.075748-515-sources.jar: com/ejianc/business/middlemeasurement/bean/DesignsubcontractnodeEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.DesignsubcontractnodedetailEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 设计分包节点报量申请
 *
 * @author generator
 *
 */
 @TableName("ejc_middlemeasurement_designsubcontractnode")
public class DesignsubcontractnodeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="settlement_date")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date settlementDate; // 结算日期
    @TableField(value="settlement_code")
    private java.lang.String settlementCode; // 结算编号
    @TableField(value="contract")
    private java.lang.Long contract; // 合同
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编号
    @TableField(value="design_units")
    private java.lang.Long designUnits; // 设计单位
    @TableField(value="design_units_name")
    private java.lang.String designUnitsName; // 设计单位名称
    @TableField(value="design_content")
    private java.lang.String designContent; // 设计内容
    @TableField(value="start_date")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date startDate; // 开始日期
    @TableField(value="end_date")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date endDate; // 截止时间
    @TableField(value="progress_settlement_times")
    private java.lang.Integer progressSettlementTimes; // 进度结算次数
    @TableField(value="image_completion_site")
    private java.lang.String imageCompletionSite; // 完成形象部位
    @TableField(value="phone")
    private java.lang.String phone; // 联系电话
    @TableField(value="excluding_tax_price")
    private java.math.BigDecimal excludingTaxPrice; // 不含税金额
    @TableField(value="tax")
    private java.math.BigDecimal tax; // 税金
    @TableField(value="tax_price_total")
    private java.math.BigDecimal taxPriceTotal; // 价税合计
    @TableField(value="schedule_confirm")
    private java.lang.String scheduleConfirm; // 成功确认及设计进度确认（设计总负责人）
    @TableField(value="quality")
    private java.lang.String quality; // 质量（设计总负责人）
    @TableField(value="deductions")
    private java.lang.String deductions; // 各种扣款项（商务工程师）
    @TableField(value="verify_and_other")
    private java.lang.String verifyAndOther; // 核实以上及其他相关工作（项目分管副总）
    @TableField(value="verify_quantities")
    private java.lang.String verifyQuantities; // 核实本次确认工程量、各部门奖罚、转扣或分摊费用等。（项目商务经理）
    @TableField(value="is_settlement")
    private Integer isSettlement; // 是否归集状态 0 未归集 1 归集

    @TableField(value="ex_tax_total_this_audit_all")
    private java.math.BigDecimal exTaxTotalThisAuditAll; // 除税合价（本期审核汇总）
    @TableField(value="in_tax_total_this_audit_all")
    private java.math.BigDecimal inTaxTotalThisAuditAll; // 含税合价（本期审核汇总）
    @TableField(value="ex_tax_total_cumulative_audit_all")
    private java.math.BigDecimal exTaxTotalCumulativeAuditAll; // 除税合价（累计审核汇总）
    @TableField(value="in_tax_total_cumulative_audit_all")
    private java.math.BigDecimal inTaxTotalCumulativeAuditAll; // 含税合价（累计审核汇总）
    @TableField(value="last_ex_tax_total_cumulative_audit_all")
    private java.math.BigDecimal lastExTaxTotalCumulativeAuditAll; // 往期除税合价（累计审核）
    @TableField(value="last_in_tax_total_cumulative_audit_all")
    private java.math.BigDecimal lastInTaxTotalCumulativeAuditAll; // 往期含税合价（累计审核）

    public BigDecimal getLastExTaxTotalCumulativeAuditAll() {
        return lastExTaxTotalCumulativeAuditAll;
    }

    public void setLastExTaxTotalCumulativeAuditAll(BigDecimal lastExTaxTotalCumulativeAuditAll) {
        this.lastExTaxTotalCumulativeAuditAll = lastExTaxTotalCumulativeAuditAll;
    }

    public BigDecimal getLastInTaxTotalCumulativeAuditAll() {
        return lastInTaxTotalCumulativeAuditAll;
    }

    public void setLastInTaxTotalCumulativeAuditAll(BigDecimal lastInTaxTotalCumulativeAuditAll) {
        this.lastInTaxTotalCumulativeAuditAll = lastInTaxTotalCumulativeAuditAll;
    }

    @TableField(exist=false)
    @SubEntity(serviceName="designsubcontractnodedetailService",pidName = "mid")
    private List<DesignsubcontractnodedetailEntity> designsubcontractnodedetailEntities = new ArrayList<>(); // 设计分包节点报量申请子表

    public BigDecimal getExTaxTotalThisAuditAll() {
        return exTaxTotalThisAuditAll;
    }

    public void setExTaxTotalThisAuditAll(BigDecimal exTaxTotalThisAuditAll) {
        this.exTaxTotalThisAuditAll = exTaxTotalThisAuditAll;
    }

    public BigDecimal getInTaxTotalThisAuditAll() {
        return inTaxTotalThisAuditAll;
    }

    public void setInTaxTotalThisAuditAll(BigDecimal inTaxTotalThisAuditAll) {
        this.inTaxTotalThisAuditAll = inTaxTotalThisAuditAll;
    }

    public BigDecimal getExTaxTotalCumulativeAuditAll() {
        return exTaxTotalCumulativeAuditAll;
    }

    public void setExTaxTotalCumulativeAuditAll(BigDecimal exTaxTotalCumulativeAuditAll) {
        this.exTaxTotalCumulativeAuditAll = exTaxTotalCumulativeAuditAll;
    }

    public BigDecimal getInTaxTotalCumulativeAuditAll() {
        return inTaxTotalCumulativeAuditAll;
    }

    public void setInTaxTotalCumulativeAuditAll(BigDecimal inTaxTotalCumulativeAuditAll) {
        this.inTaxTotalCumulativeAuditAll = inTaxTotalCumulativeAuditAll;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 结算日期
     */
    public java.util.Date getSettlementDate() {
        return settlementDate;
    }

    /**
     * 结算日期
     */
    public void setSettlementDate(java.util.Date settlementDate) {
        this.settlementDate = settlementDate;
    }
    /**
     * 结算编号
     */
    public java.lang.String getSettlementCode() {
        return settlementCode;
    }

    /**
     * 结算编号
     */
    public void setSettlementCode(java.lang.String settlementCode) {
        this.settlementCode = settlementCode;
    }
    /**
     * 合同
     */
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 设计单位
     */
    @ReferSerialTransfer(referCode = "support-supplier")
    public java.lang.Long getDesignUnits() {
        return designUnits;
    }

    /**
     * 设计单位
     */
    @ReferDeserialTransfer
    public void setDesignUnits(java.lang.Long designUnits) {
        this.designUnits = designUnits;
    }
    /**
     * 设计单位名称
     */

    public java.lang.String getDesignUnitsName() {
        return designUnitsName;
    }

    /**
     * 设计单位名称
     */

    public void setDesignUnitsName(java.lang.String designUnitsName) {
        this.designUnitsName = designUnitsName;
    }
    /**
     * 设计内容
     */
    public java.lang.String getDesignContent() {
        return designContent;
    }

    /**
     * 设计内容
     */
    public void setDesignContent(java.lang.String designContent) {
        this.designContent = designContent;
    }
    /**
     * 开始日期
     */
    public java.util.Date getStartDate() {
        return startDate;
    }

    /**
     * 开始日期
     */
    public void setStartDate(java.util.Date startDate) {
        this.startDate = startDate;
    }
    /**
     * 截止时间
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 截止时间
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 进度结算次数
     */
    public java.lang.Integer getProgressSettlementTimes() {
        return progressSettlementTimes;
    }

    /**
     * 进度结算次数
     */
    public void setProgressSettlementTimes(java.lang.Integer progressSettlementTimes) {
        this.progressSettlementTimes = progressSettlementTimes;
    }
    /**
     * 完成形象部位
     */
    public java.lang.String getImageCompletionSite() {
        return imageCompletionSite;
    }

    /**
     * 完成形象部位
     */
    public void setImageCompletionSite(java.lang.String imageCompletionSite) {
        this.imageCompletionSite = imageCompletionSite;
    }
    /**
     * 联系电话
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系电话
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 不含税金额
     */
    public java.math.BigDecimal getExcludingTaxPrice() {
        return excludingTaxPrice;
    }

    /**
     * 不含税金额
     */
    public void setExcludingTaxPrice(java.math.BigDecimal excludingTaxPrice) {
        this.excludingTaxPrice = excludingTaxPrice;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 价税合计
     */
    public java.math.BigDecimal getTaxPriceTotal() {
        return taxPriceTotal;
    }

    /**
     * 价税合计
     */
    public void setTaxPriceTotal(java.math.BigDecimal taxPriceTotal) {
        this.taxPriceTotal = taxPriceTotal;
    }
    /**
     * 成功确认及设计进度确认（设计总负责人）
     */
    public java.lang.String getScheduleConfirm() {
        return scheduleConfirm;
    }

    /**
     * 成功确认及设计进度确认（设计总负责人）
     */
    public void setScheduleConfirm(java.lang.String scheduleConfirm) {
        this.scheduleConfirm = scheduleConfirm;
    }
    /**
     * 质量（设计总负责人）
     */
    public java.lang.String getQuality() {
        return quality;
    }

    /**
     * 质量（设计总负责人）
     */
    public void setQuality(java.lang.String quality) {
        this.quality = quality;
    }
    /**
     * 各种扣款项（商务工程师）
     */
    public java.lang.String getDeductions() {
        return deductions;
    }

    /**
     * 各种扣款项（商务工程师）
     */
    public void setDeductions(java.lang.String deductions) {
        this.deductions = deductions;
    }
    /**
     * 核实以上及其他相关工作（项目分管副总）
     */
    public java.lang.String getVerifyAndOther() {
        return verifyAndOther;
    }

    /**
     * 核实以上及其他相关工作（项目分管副总）
     */
    public void setVerifyAndOther(java.lang.String verifyAndOther) {
        this.verifyAndOther = verifyAndOther;
    }
    /**
     * 核实本次确认工程量、各部门奖罚、转扣或分摊费用等。（项目商务经理）
     */
    public java.lang.String getVerifyQuantities() {
        return verifyQuantities;
    }

    /**
     * 核实本次确认工程量、各部门奖罚、转扣或分摊费用等。（项目商务经理）
     */
    public void setVerifyQuantities(java.lang.String verifyQuantities) {
        this.verifyQuantities = verifyQuantities;
    }

    /**
     * 设计分包节点报量申请子表
     */
    public List<DesignsubcontractnodedetailEntity> getDesignsubcontractnodedetailEntities() {
        return designsubcontractnodedetailEntities;
    }

    /**
     * 设计分包节点报量申请子表
     */
    public void setDesignsubcontractnodedetailEntities(List<DesignsubcontractnodedetailEntity> designsubcontractnodedetailEntities) {
        this.designsubcontractnodedetailEntities = designsubcontractnodedetailEntities;
    }

    public Integer getIsSettlement() {
        return isSettlement;
    }

    public void setIsSettlement(Integer isSettlement) {
        this.isSettlement = isSettlement;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20241126.022138-621-sources.jar: com/ejianc/business/middlemeasurement/bean/DesignsubcontractnodeEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.DesignsubcontractnodedetailEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 设计分包节点报量申请
 *
 * @author generator
 *
 */
 @TableName("ejc_middlemeasurement_designsubcontractnode")
public class DesignsubcontractnodeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="settlement_date")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date settlementDate; // 结算日期
    @TableField(value="settlement_code")
    private java.lang.String settlementCode; // 结算编号
    @TableField(value="contract")
    private java.lang.Long contract; // 合同
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="contract_code")
    private java.lang.String contractCode; // 合同编号
    @TableField(value="design_units")
    private java.lang.Long designUnits; // 设计单位
    @TableField(value="design_units_name")
    private java.lang.String designUnitsName; // 设计单位名称
    @TableField(value="design_content")
    private java.lang.String designContent; // 设计内容
    @TableField(value="start_date")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date startDate; // 开始日期
    @TableField(value="end_date")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date endDate; // 截止时间
    @TableField(value="progress_settlement_times")
    private java.lang.Integer progressSettlementTimes; // 进度结算次数
    @TableField(value="image_completion_site")
    private java.lang.String imageCompletionSite; // 完成形象部位
    @TableField(value="phone")
    private java.lang.String phone; // 联系电话
    @TableField(value="excluding_tax_price")
    private java.math.BigDecimal excludingTaxPrice; // 不含税金额
    @TableField(value="tax")
    private java.math.BigDecimal tax; // 税金
    @TableField(value="tax_price_total")
    private java.math.BigDecimal taxPriceTotal; // 价税合计
    @TableField(value="schedule_confirm")
    private java.lang.String scheduleConfirm; // 成功确认及设计进度确认（设计总负责人）
    @TableField(value="quality")
    private java.lang.String quality; // 质量（设计总负责人）
    @TableField(value="deductions")
    private java.lang.String deductions; // 各种扣款项（商务工程师）
    @TableField(value="verify_and_other")
    private java.lang.String verifyAndOther; // 核实以上及其他相关工作（项目分管副总）
    @TableField(value="verify_quantities")
    private java.lang.String verifyQuantities; // 核实本次确认工程量、各部门奖罚、转扣或分摊费用等。（项目商务经理）
    @TableField(value="is_settlement")
    private Integer isSettlement; // 是否归集状态 0 未归集 1 归集

    @TableField(value="ex_tax_total_this_audit_all")
    private java.math.BigDecimal exTaxTotalThisAuditAll; // 除税合价（本期审核汇总）
    @TableField(value="in_tax_total_this_audit_all")
    private java.math.BigDecimal inTaxTotalThisAuditAll; // 含税合价（本期审核汇总）
    @TableField(value="ex_tax_total_cumulative_audit_all")
    private java.math.BigDecimal exTaxTotalCumulativeAuditAll; // 除税合价（累计审核汇总）
    @TableField(value="in_tax_total_cumulative_audit_all")
    private java.math.BigDecimal inTaxTotalCumulativeAuditAll; // 含税合价（累计审核汇总）
    @TableField(value="last_ex_tax_total_cumulative_audit_all")
    private java.math.BigDecimal lastExTaxTotalCumulativeAuditAll; // 往期除税合价（累计审核）
    @TableField(value="last_in_tax_total_cumulative_audit_all")
    private java.math.BigDecimal lastInTaxTotalCumulativeAuditAll; // 往期含税合价（累计审核）
    @TableField(value="project_create_time")
    private Date projectCreateTime; // 项目创建日期
    @TableField(value="org_status_order")
    private Integer orgStatusOrder; // 二级组织排序

    public BigDecimal getLastExTaxTotalCumulativeAuditAll() {
        return lastExTaxTotalCumulativeAuditAll;
    }

    public void setLastExTaxTotalCumulativeAuditAll(BigDecimal lastExTaxTotalCumulativeAuditAll) {
        this.lastExTaxTotalCumulativeAuditAll = lastExTaxTotalCumulativeAuditAll;
    }

    public BigDecimal getLastInTaxTotalCumulativeAuditAll() {
        return lastInTaxTotalCumulativeAuditAll;
    }

    public void setLastInTaxTotalCumulativeAuditAll(BigDecimal lastInTaxTotalCumulativeAuditAll) {
        this.lastInTaxTotalCumulativeAuditAll = lastInTaxTotalCumulativeAuditAll;
    }

    @TableField(exist=false)
    @SubEntity(serviceName="designsubcontractnodedetailService",pidName = "mid")
    private List<DesignsubcontractnodedetailEntity> designsubcontractnodedetailEntities = new ArrayList<>(); // 设计分包节点报量申请子表

    public BigDecimal getExTaxTotalThisAuditAll() {
        return exTaxTotalThisAuditAll;
    }

    public void setExTaxTotalThisAuditAll(BigDecimal exTaxTotalThisAuditAll) {
        this.exTaxTotalThisAuditAll = exTaxTotalThisAuditAll;
    }

    public BigDecimal getInTaxTotalThisAuditAll() {
        return inTaxTotalThisAuditAll;
    }

    public void setInTaxTotalThisAuditAll(BigDecimal inTaxTotalThisAuditAll) {
        this.inTaxTotalThisAuditAll = inTaxTotalThisAuditAll;
    }

    public BigDecimal getExTaxTotalCumulativeAuditAll() {
        return exTaxTotalCumulativeAuditAll;
    }

    public void setExTaxTotalCumulativeAuditAll(BigDecimal exTaxTotalCumulativeAuditAll) {
        this.exTaxTotalCumulativeAuditAll = exTaxTotalCumulativeAuditAll;
    }

    public BigDecimal getInTaxTotalCumulativeAuditAll() {
        return inTaxTotalCumulativeAuditAll;
    }

    public void setInTaxTotalCumulativeAuditAll(BigDecimal inTaxTotalCumulativeAuditAll) {
        this.inTaxTotalCumulativeAuditAll = inTaxTotalCumulativeAuditAll;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 结算日期
     */
    public java.util.Date getSettlementDate() {
        return settlementDate;
    }

    /**
     * 结算日期
     */
    public void setSettlementDate(java.util.Date settlementDate) {
        this.settlementDate = settlementDate;
    }
    /**
     * 结算编号
     */
    public java.lang.String getSettlementCode() {
        return settlementCode;
    }

    /**
     * 结算编号
     */
    public void setSettlementCode(java.lang.String settlementCode) {
        this.settlementCode = settlementCode;
    }
    /**
     * 合同
     */
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 设计单位
     */
    @ReferSerialTransfer(referCode = "support-supplier")
    public java.lang.Long getDesignUnits() {
        return designUnits;
    }

    /**
     * 设计单位
     */
    @ReferDeserialTransfer
    public void setDesignUnits(java.lang.Long designUnits) {
        this.designUnits = designUnits;
    }
    /**
     * 设计单位名称
     */

    public java.lang.String getDesignUnitsName() {
        return designUnitsName;
    }

    /**
     * 设计单位名称
     */

    public void setDesignUnitsName(java.lang.String designUnitsName) {
        this.designUnitsName = designUnitsName;
    }
    /**
     * 设计内容
     */
    public java.lang.String getDesignContent() {
        return designContent;
    }

    /**
     * 设计内容
     */
    public void setDesignContent(java.lang.String designContent) {
        this.designContent = designContent;
    }
    /**
     * 开始日期
     */
    public java.util.Date getStartDate() {
        return startDate;
    }

    /**
     * 开始日期
     */
    public void setStartDate(java.util.Date startDate) {
        this.startDate = startDate;
    }
    /**
     * 截止时间
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 截止时间
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 进度结算次数
     */
    public java.lang.Integer getProgressSettlementTimes() {
        return progressSettlementTimes;
    }

    /**
     * 进度结算次数
     */
    public void setProgressSettlementTimes(java.lang.Integer progressSettlementTimes) {
        this.progressSettlementTimes = progressSettlementTimes;
    }
    /**
     * 完成形象部位
     */
    public java.lang.String getImageCompletionSite() {
        return imageCompletionSite;
    }

    /**
     * 完成形象部位
     */
    public void setImageCompletionSite(java.lang.String imageCompletionSite) {
        this.imageCompletionSite = imageCompletionSite;
    }
    /**
     * 联系电话
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系电话
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 不含税金额
     */
    public java.math.BigDecimal getExcludingTaxPrice() {
        return excludingTaxPrice;
    }

    /**
     * 不含税金额
     */
    public void setExcludingTaxPrice(java.math.BigDecimal excludingTaxPrice) {
        this.excludingTaxPrice = excludingTaxPrice;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 价税合计
     */
    public java.math.BigDecimal getTaxPriceTotal() {
        return taxPriceTotal;
    }

    /**
     * 价税合计
     */
    public void setTaxPriceTotal(java.math.BigDecimal taxPriceTotal) {
        this.taxPriceTotal = taxPriceTotal;
    }
    /**
     * 成功确认及设计进度确认（设计总负责人）
     */
    public java.lang.String getScheduleConfirm() {
        return scheduleConfirm;
    }

    /**
     * 成功确认及设计进度确认（设计总负责人）
     */
    public void setScheduleConfirm(java.lang.String scheduleConfirm) {
        this.scheduleConfirm = scheduleConfirm;
    }
    /**
     * 质量（设计总负责人）
     */
    public java.lang.String getQuality() {
        return quality;
    }

    /**
     * 质量（设计总负责人）
     */
    public void setQuality(java.lang.String quality) {
        this.quality = quality;
    }
    /**
     * 各种扣款项（商务工程师）
     */
    public java.lang.String getDeductions() {
        return deductions;
    }

    /**
     * 各种扣款项（商务工程师）
     */
    public void setDeductions(java.lang.String deductions) {
        this.deductions = deductions;
    }
    /**
     * 核实以上及其他相关工作（项目分管副总）
     */
    public java.lang.String getVerifyAndOther() {
        return verifyAndOther;
    }

    /**
     * 核实以上及其他相关工作（项目分管副总）
     */
    public void setVerifyAndOther(java.lang.String verifyAndOther) {
        this.verifyAndOther = verifyAndOther;
    }
    /**
     * 核实本次确认工程量、各部门奖罚、转扣或分摊费用等。（项目商务经理）
     */
    public java.lang.String getVerifyQuantities() {
        return verifyQuantities;
    }

    /**
     * 核实本次确认工程量、各部门奖罚、转扣或分摊费用等。（项目商务经理）
     */
    public void setVerifyQuantities(java.lang.String verifyQuantities) {
        this.verifyQuantities = verifyQuantities;
    }

    /**
     * 设计分包节点报量申请子表
     */
    public List<DesignsubcontractnodedetailEntity> getDesignsubcontractnodedetailEntities() {
        return designsubcontractnodedetailEntities;
    }

    /**
     * 设计分包节点报量申请子表
     */
    public void setDesignsubcontractnodedetailEntities(List<DesignsubcontractnodedetailEntity> designsubcontractnodedetailEntities) {
        this.designsubcontractnodedetailEntities = designsubcontractnodedetailEntities;
    }

    public Integer getIsSettlement() {
        return isSettlement;
    }

    public void setIsSettlement(Integer isSettlement) {
        this.isSettlement = isSettlement;
    }
}
